@@ -177,6 +177,7 @@ it under the same terms as Perl itself.
 
 @@ .travis.yml
 language: perl
+sudo: false
 perl:
   - "5.12"
   - "5.14"
@@ -198,6 +199,7 @@ Revision history for Perl extension <% $dist %>
 /Build.bat
 /blib
 /Makefile
+/pm_to_blib
 
 /carton.lock
 /.carton/
