@@ -43,7 +43,7 @@ has module_maker => (
             $klass = $klass =~ s/^\+// ? $klass : "Minilla::ModuleMaker::$klass";
             return $klass->new();
         }
-        Minilla::ModuleMaker::ModuleBuild->new()
+        Minilla::ModuleMaker::ModuleBuildTiny->new()
     },
     lazy => 1,
 );
@@ -111,12 +111,6 @@ sub allow_pureperl {
     $self->config->{allow_pureperl} ? 1 : 0;
 }
 
-sub module_build_version {
-    my $self = shift;
-    # --pureperl-only support was added in 0.4005
-    $self->allow_pureperl ? 0.4005 : 0.38;
-}
-
 sub version {
     my $self = shift;
     my $version = $self->config->{version} || $self->metadata->version;
@@ -225,12 +219,35 @@ sub config {
         if ($err) {
             errorf("TOML error in %s: %s\n", $toml_path, $err);
         }
+        $self->_patch_config_for_mb($conf) unless $conf->{module_maker};
         $conf;
     } else {
         +{};
     }
 }
 
+sub _patch_config_for_mb {
+    my($self, $conf) = @_;
+
+    if (exists $conf->{build} or exists $conf->{XSUtil}) {
+        warn <<WARN unless $self->{__already_warned}++;
+!
+! WARNING:
+! module_maker is not set in your Minilla config (minil.toml), but found [build] or [XSUtil] section in it.
+! Defaulting to Module::Build, but you're suggested to add the following to your minil.toml:
+!
+!   module_maker="ModuleBuild"
+!
+! This friendly warning will go away in the next major release, and Minilla will default to ModuleBuildTiny
+! when module_maker is not explicitly set in minil.toml.
+!
+WARN
+        $conf->{module_maker} = "ModuleBuild";
+    }
+
+    return;
+}
+
 sub c_source {
     my $self = shift;
     $self->config->{c_source} ? join(' ', @{$self->config->{c_source}}) : '';
@@ -468,9 +485,9 @@ sub extract_git_info {
     my $bugtracker;
     my $repository;
     my $homepage;
-    if ( `git remote show -n origin` =~ /URL: (.*)$/m && $1 ne 'origin' ) {
+    if ( my $registered_url = `git config --get remote.origin.url` ) {
+        $registered_url =~ s/\n//g;
         # XXX Make it public clone URL, but this only works with github
-        my $registered_url = $1;
         if ($registered_url =~ /github\.com/) {
             my ($user, $repo) = $registered_url =~ m{
                 github\.com
@@ -613,6 +630,9 @@ sub regenerate_readme_md {
                 if ($badge eq 'coveralls') {
                     push @badges, "[![Coverage Status](https://img.shields.io/coveralls/$user_name/$repository_name/master.svg?style=flat)](https://coveralls.io/r/$user_name/$repository_name?branch=master)"
                 }
+                if ($badge eq 'codecov') {
+                    push @badges, "[![Coverage Status](http://codecov.io/github/$user_name/$repository_name/coverage.svg?branch=master)](https://codecov.io/github/$user_name/$repository_name?branch=master)";
+                }
                 if ($badge eq 'gitter') {
                     push @badges, "[![Gitter chat](https://badges.gitter.im/$user_name/$repository_name.png)](https://gitter.im/$user_name/$repository_name)";
                 }
